<?php
/**
* About options
*
* @package Graduate_Pro
* @since Graduate Pro 1.0
*/

// Add About enable section
$wp_customize->add_section( 'graduate_pro_about_content_section', array(
	'title'             => esc_html__( 'About Section','graduate-pro' ),
	'description'       => esc_html__( 'About section options.', 'graduate-pro' ),
	'panel'             => 'graduate_pro_section_options_panel'
) );

// Add About enable setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[about_content_enable]', array(
	'default'           => $options['about_content_enable'],
	'sanitize_callback' => 'graduate_pro_sanitize_select'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[about_content_enable]', array(
	'label'             => esc_html__( 'Enable on', 'graduate-pro' ),
	'section'           => 'graduate_pro_about_content_section',
	'type'              => 'select',
	'choices'           => graduate_pro_enable_disable_options()
) );

// Add About type setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[about_content_type]', array(
	'default'           => $options['about_content_type'],
	'sanitize_callback' => 'graduate_pro_sanitize_select'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[about_content_type]', array(
	'label'           => esc_html__( 'Content Type', 'graduate-pro' ),
	'section'         => 'graduate_pro_about_content_section',
	'type'            => 'select',
	'active_callback' => 'graduate_pro_is_about_content_active',
	'choices'         => graduate_pro_about_content_type()
) );

// Page Content Type
$wp_customize->add_setting( 'graduate_pro_theme_options[about_content_page]', array(
	'sanitize_callback' => 'graduate_pro_sanitize_page'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[about_content_page]', array(
	'label'           	=> esc_html__( 'Select Page', 'graduate-pro' ),
	'section'        	=> 'graduate_pro_about_content_section',
	'active_callback' 	=> 'graduate_pro_is_about_content_page_active',
	'type'				=> 'dropdown-pages'
) );

// Post Content Type
$wp_customize->add_setting( 'graduate_pro_theme_options[about_content_post]', array(
	'sanitize_callback' => 'graduate_pro_sanitize_number_range',
	'validate_callback' => 'graduate_pro_validate_post_id'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[about_content_post]', array(
	'label'           	=> esc_html__( 'Input Post ID', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_about_content_section',
	'active_callback' 	=> 'graduate_pro_is_about_content_post_active',
	'type'				=> 'number',
	'input_attrs'     	=> array(
		'min'	=> 1,
		'style' => 'width:100px'
		)
) );

// Excerpt Length
$wp_customize->add_setting( 'graduate_pro_theme_options[about_content_excerpt_length]', array(
	'default'           => $options['about_content_excerpt_length'],
	'sanitize_callback' => 'graduate_pro_sanitize_number_range',
	'validate_callback' => 'graduate_pro_validate_about_content_excerpt_length'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[about_content_excerpt_length]', array(
	'label'           	=> esc_html__( 'Excerpt Length', 'graduate-pro' ),
	'description'		=> esc_html__( 'Input number of words to show in description.', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_about_content_section',
	'active_callback' 	=> 'graduate_pro_is_about_content_not_demo',
	'type'				=> 'number',
	'input_attrs'     	=> array(
		'min'	=> 25,
		'max'	=> 100,
		'style' => 'width:100px'
		)
) );